@@ -10,7 +10,7 @@ import numbers
 from .api import library
 from .cdefs.structures import MagickPixelPacket, PixelInfo
 from .compat import binary, text
-from .resource import Resource
+from .resource import Resource, genesis
 from .version import MAGICK_VERSION_NUMBER, MAGICK_HDRI, QUANTUM_DEPTH
 
 __all__ = 'Color', 'scale_quantum_to_int8'
@@ -124,6 +124,9 @@ class Color(Resource):
 
     def __enter__(self):
         if self.allocated < 1:
+            # As of 0x710, we must call MagickWandGenesis before allocate of
+            # Wand's Resource & ImageMagick PixelWand.
+            genesis()
             with self.allocate():
                 # Initialize resource.
                 self.resource = library.NewPixelWand()
@@ -328,7 +331,7 @@ class Color(Resource):
         .. versionadded:: 0.3.0
 
         """
-        return scale_quantum_to_int8(self.alpha_quantum)
+        return max(0, min(255, int(255.0 * self.alpha)))
 
     @alpha_int8.setter
     def alpha_int8(self, value):
@@ -377,7 +380,7 @@ class Color(Resource):
 
         .. versionadded:: 0.5.1
         """
-        return scale_quantum_to_int8(self.black_quantum)
+        return max(0, min(255, int(255.0 * self.black)))
 
     @black_int8.setter
     def black_int8(self, value):
@@ -422,7 +425,7 @@ class Color(Resource):
         .. versionadded:: 0.3.0
 
         """
-        return scale_quantum_to_int8(self.blue_quantum)
+        return max(0, min(255, int(255.0 * self.blue)))
 
     @blue_int8.setter
     def blue_int8(self, value):
@@ -471,7 +474,7 @@ class Color(Resource):
 
         .. versionadded:: 0.5.1
         """
-        return scale_quantum_to_int8(self.cyan_quantum)
+        return max(0, min(255, int(255.0 * self.cyan)))
 
     @cyan_int8.setter
     def cyan_int8(self, value):
@@ -530,7 +533,7 @@ class Color(Resource):
         .. versionadded:: 0.3.0
 
         """
-        return scale_quantum_to_int8(self.green_quantum)
+        return max(0, min(255, int(255.0 * self.green)))
 
     @green_int8.setter
     def green_int8(self, value):
@@ -579,7 +582,7 @@ class Color(Resource):
 
         .. versionadded:: 0.5.1
         """
-        return scale_quantum_to_int8(self.magenta_quantum)
+        return max(0, min(255, int(255.0 * self.magenta)))
 
     @magenta_int8.setter
     def magenta_int8(self, value):
@@ -641,7 +644,7 @@ class Color(Resource):
         .. versionadded:: 0.3.0
 
         """
-        return scale_quantum_to_int8(self.red_quantum)
+        return max(0, min(255, int(255.0 * self.red)))
 
     @red_int8.setter
     def red_int8(self, value):
@@ -701,7 +704,7 @@ class Color(Resource):
 
         .. versionadded:: 0.5.1
         """
-        return scale_quantum_to_int8(self.yellow_quantum)
+        return max(0, min(255, int(255.0 * self.yellow)))
 
     @yellow_int8.setter
     def yellow_int8(self, value):
@@ -749,6 +752,8 @@ def scale_quantum_to_int8(quantum):
     """Straightforward port of :c:func:`ScaleQuantumToChar()` inline
     function.
 
+    .. deprecated:: 0.6.6
+
     :param quantum: quantum value
     :type quantum: :class:`numbers.Integral`
     :returns: 8bit integer of the given ``quantum`` value
